==> istio-model-v1alpha3-5.11.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/SidecarBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SidecarBuilder extends io.fabric8.istio.api.networking.v1alpha3.SidecarFluentImpl<io.fabric8.istio.api.networking.v1alpha3.SidecarBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1alpha3.Sidecar,io.fabric8.istio.api.networking.v1alpha3.SidecarBuilder>{
  public SidecarBuilder() {
    this(false);
  }
  public SidecarBuilder(java.lang.Boolean validationEnabled) {
    this(new Sidecar(), validationEnabled);
  }
  public SidecarBuilder(io.fabric8.istio.api.networking.v1alpha3.SidecarFluent<?> fluent) {
    this(fluent, false);
  }
  public SidecarBuilder(io.fabric8.istio.api.networking.v1alpha3.SidecarFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Sidecar(), validationEnabled);
  }
  public SidecarBuilder(io.fabric8.istio.api.networking.v1alpha3.SidecarFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.Sidecar instance) {
    this(fluent, instance, false);
  }
  public SidecarBuilder(io.fabric8.istio.api.networking.v1alpha3.SidecarFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.Sidecar instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public SidecarBuilder(io.fabric8.istio.api.networking.v1alpha3.Sidecar instance) {
    this(instance,false);
  }
  public SidecarBuilder(io.fabric8.istio.api.networking.v1alpha3.Sidecar instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1alpha3.SidecarFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1alpha3.Sidecar build() {
    Sidecar buildable = new Sidecar(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SidecarBuilder that = (SidecarBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/SidecarBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SidecarBuilder extends SidecarFluentImpl<SidecarBuilder> implements VisitableBuilder<Sidecar,SidecarBuilder>{
  public SidecarBuilder() {
    this(false);
  }
  public SidecarBuilder(Boolean validationEnabled) {
    this(new Sidecar(), validationEnabled);
  }
  public SidecarBuilder(SidecarFluent<?> fluent) {
    this(fluent, false);
  }
  public SidecarBuilder(SidecarFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Sidecar(), validationEnabled);
  }
  public SidecarBuilder(SidecarFluent<?> fluent,Sidecar instance) {
    this(fluent, instance, false);
  }
  public SidecarBuilder(SidecarFluent<?> fluent,Sidecar instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public SidecarBuilder(Sidecar instance) {
    this(instance,false);
  }
  public SidecarBuilder(Sidecar instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  SidecarFluent<?> fluent;
  Boolean validationEnabled;
  public Sidecar build() {
    Sidecar buildable = new Sidecar(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
